@@ -30,7 +30,6 @@ tot_atoms_uc = int(np.sum(n_atom_unit_cell))
 tot_atoms_conventional_cell = int(np.sum(n_atom_conventional_cell)) 
 N1N2N3 = N1*N2*N3 # Number of cells
 N = N1*N2*N3*tot_atoms_uc    # Number of atoms
-masses, masses_for_animation = util.repeat_masses(Masses, n_atom_conventional_cell, n_atom_unit_cell, N1, N2, N3)
 cH = 1.066*1e-6 # to [H]
 cev = 2.902*1e-05 # to [ev]
 kbH = 3.1668085639379003*1e-06# a.u. [H/K]
@@ -49,7 +48,7 @@ print()
 print('Now calculating velocities...')
 
 Nqpoints, qpoints_scaled, ks, freqs, eigvecs, distances, Hk = read.read_phonopy(file_eigenvectors, tot_atoms_uc)
-Ruc, R0 = read.read_SPOSCAR(file_initial_conf, N1N2N3, N, n_atom_conventional_cell, n_atom_unit_cell)                       #rhombo or avg R0
+Ruc, R0, masses, masses_for_animation = read.read_SPOSCAR_and_masses(file_initial_conf, n_atom_conventional_cell, n_atom_unit_cell, Masses)                       #rhombo or avg R0
 
 Rt = np.loadtxt(file_trajectory)[:,1:]
 Num_timesteps = int(len(Rt[:,0]))
