@@ -216,10 +216,12 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     R0 = np.dot(h,S.T).T*conv_factor
     
     Ruc = np.zeros((tot_atoms_primitive,3))
+    c = 0
     for i in range(len(n_atom_conventional_cell)):
         n = n_atom_conventional_cell[i]
         for j in range(n):
-            Ruc[i+j] = R0[(i+j)*N1N2N3]
+            Ruc[c+j] = R0[(c+j)*N1N2N3]
+        c = c + j+1
     R0 = np.repeat(R0,3,axis=0)
     
     
